
;**************************************************************************
;*                             LCD                                        *
;**************************************************************************
;*          2 char LCD display connected to PIC                           *
;*          3 buttons used                                                *
;**************************************************************************
;*          v 1.18 - 02.12.2008                                           *
;**************************************************************************
;*          Hardw.: PIC16F628A used                                       *
;*          OSC.......: Internal osc. used                                *
;*          POWER.....:  3x1,2V accu or included 1F capacitor (~30 min)   *
;**************************************************************************

W                            EQU     H'0000'
F                            EQU     H'0001'

;----- Register Files------------------------------------------------------

INDF                         EQU     H'0000'
TMR0                         EQU     H'0001'
PCL                          EQU     H'0002'
STATUS                       EQU     H'0003'
FSR                          EQU     H'0004'
PORTA                        EQU     H'0005'
PORTB                        EQU     H'0006'

INTCON                       EQU     H'000B'
OPTION_REG                   EQU     H'0081'
TRISA                        EQU     H'0085'
TRISB                        EQU     H'0086'
CMCON                        EQU     H'001F'

;----- STATUS Bits --------------------------------------------------------
IRP                          EQU     H'0007'
RP1                          EQU     H'0006'
RP0                          EQU     H'0005'
NOT_TO                       EQU     H'0004'
NOT_PD                       EQU     H'0003'
Z                            EQU     H'0002'
DC                           EQU     H'0001'
C                            EQU     H'0000'

;==========================================================================
;
;       RAM Definition
;
;==========================================================================

    __MAXRAM H'01FF'
    __BADRAM H'07'-H'09', H'0D', H'13'-H'14', H'1B'-H'1E'
    __BADRAM H'87'-H'89', H'8D', H'8F'-H'91', H'93'-H'97', H'9E'
    __BADRAM H'105', H'107'-H'109', H'10C'-H'11F', H'150'-H'16F'
    __BADRAM H'185', H'187'-H'189', H'18C'-H'1EF'

;==========================================================================
;
;       Configuration Bits
;
;==========================================================================

_BODEN_ON                    EQU     H'3FFF'
_BODEN_OFF                   EQU     H'3FBF'
_CP_ALL                      EQU     H'03FF'
_CP_75                       EQU     H'17FF'
_CP_50                       EQU     H'2BFF'
_CP_OFF                      EQU     H'3FFF'
_DATA_CP_ON                  EQU     H'3EFF'
_DATA_CP_OFF                 EQU     H'3FFF'
_PWRTE_OFF                   EQU     H'3FFF'
_PWRTE_ON                    EQU     H'3FF7'
_WDT_ON                      EQU     H'3FFF'
_WDT_OFF                     EQU     H'3FFB'
_LVP_ON                      EQU     H'3FFF'
_LVP_OFF                     EQU     H'3F7F'
_MCLRE_ON                    EQU     H'3FFF'
_MCLRE_OFF                   EQU     H'3FDF'
_ER_OSC_CLKOUT               EQU     H'3FFF'
_ER_OSC_NOCLKOUT             EQU     H'3FFE'
_INTRC_OSC_CLKOUT            EQU     H'3FFD'
_INTRC_OSC_NOCLKOUT          EQU     H'3FFC'
_EXTCLK_OSC                  EQU     H'3FEF'
_LP_OSC                      EQU     H'3FEC'
_XT_OSC                      EQU     H'3FED'
_HS_OSC                      EQU     H'3FEE'


	__CONFIG        _BODEN_OFF & _CP_OFF & _DATA_CP_OFF & _PWRTE_ON & _WDT_OFF & _LVP_OFF & _MCLRE_OFF & _INTRC_OSC_NOCLKOUT

;==========================================================================
;       Variable Definition
;==========================================================================
;INPUTS
SW1		EQU     H'00'		;SW1 is triggering RA0
SW2		EQU     H'01'		;SW2 is triggering RA1
SW3		EQU     H'02'		;SW3 is triggering RA2
SW4		EQU     H'03'		;SW4 is triggering RA3
TIMER1		EQU	H'20'		;Used in delay routine
TIMER2		EQU	H'21'		; "	"	"	
dataA		EQU	H'22'
dataB		EQU	H'23'
TIMER3		EQU	H'24'		;Used in delay routine
TIMER4		EQU	H'25'		; "	"	"	
digitA		EQU	H'26'
digitB		EQU	H'27'
button1		EQU	H'28'
button2		EQU	H'29'
button3		EQU	H'2A'

actf		EQU	H'2B'		;active function
;==========================================================================

		ORG	0		;Reset vector address
		GOTO	RESET		;goto RESET routine when boot.


;xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
;	       **********************************
;              **  RESET :  main boot routine  **
;              **********************************

RESET		MOVLW	B'00000111'	;Disable Comparator module's
		MOVWF	CMCON
		;
		BSF	STATUS,RP0	;Switch to register bank 1
					;Disable pull-ups
					;INT on rising edge
					;TMR0 to CLKOUT
					;TMR0 Incr low2high trans.
					;Prescaler assign to Timer0
					;Prescaler rate is 1:256
		MOVLW	B'11010111'	;Set PIC options (See datasheet).
		MOVWF	OPTION_REG	;Write the OPTION register.
		;
		CLRF	INTCON		;Disable interrupts

		MOVLW	B'01000000'	;RBx = 1 -> input; RBx = 0 -> output
		MOVWF	TRISB
		MOVLW	B'00100000'	;RAx = 1 -> input; RAx = 0 -> output
		MOVWF	TRISA
		BCF	STATUS,RP0	;Switch Back to reg. Bank 0
;----------------------------------------------------------------------------
;wait few seconds - if reprogramming will be required

		call	a51
		call	b51
		call	display03

		call	a50
		call	b50
		call	display03

		call	a51
		call	b51
		call	display03

		call	a50
		call	b50
		call	display03

		call	a51
		call	b51
		call	display03

		call	a50
		call	b50
		call	display03

		call	a51
		call	b51
		call	display03

		call	a50
		call	b50
		call	display03

		BSF	STATUS,RP0	;Switch to register bank 1
		MOVLW	B'00000000'	;RBx = 1 -> input; RBx = 0 -> output
		MOVWF	TRISB
		BCF	STATUS,RP0	;Switch Back to reg. Bank 0

; XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
; XXXXXXXXXX       main            XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
; XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX


		clrf	actf
		bsf	actf,D'000'		;function "0" becomes active after sw.on

		call	main_test


		clrf	digitA
		clrf	digitB
		bsf	digitA,D'007'
		bsf	digitB,D'007'

main		btfsc	actf,D'001'
		goto	main_fnc1
		btfsc	actf,D'002'
		goto	main_fnc2
		btfsc	actf,D'003'
		goto	main_fnc3

		call	showA
		call	showB
		call	display01
		goto	main

;---------------------------------------------------------------
;xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
;---------------------------------------------------------------
main_fnc1	call	showA
		call	showB
		call	display01
		goto	main
;---------------------------------------------------------------
;xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
;---------------------------------------------------------------
main_fnc2	call	showA
		call	showB
		call	display01
		incf	digitB,1
		btfsc	digitB,D'004'
		goto	inc_next
		goto	main
inc_next	clrf	digitB
		incf	digitA,1
		btfsc	digitA,D'004'
		clrf	digitA
		goto	main
;---------------------------------------------------------------
;xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
;---------------------------------------------------------------
main_fnc3	call	showA
		call	showB
		call	display01
		incf	digitB,1
		btfsc	digitB,D'003'
		goto	inc_next2
		goto	main

inc_next2	btfss	digitB,D'001'
		goto	main

		clrf	digitB
		incf	digitA,1
		btfss	digitA,D'003'
		goto	main

		btfsc	digitA,D'001'
		clrf	digitA
		goto	main
;---------------------------------------------------------------------------
;---------------------------------------------------------------------------
;A
showA		btfsc	button3,D'000'
;button3 is pressed now
		goto	b3sc

		btfsc	digitA,D'007'
		goto	sda_52
		btfsc	digitA,D'003'
		goto	sda_gt7		;>7
;<8
		btfsc	digitA,D'002'	;>3 and <8
		goto	sda_4bt7
;<4
		btfsc	digitA,D'001'
		goto	sda_2to3	;001x
		btfsc	digitA,D'000'
		goto	sda_1
;------------------------------------
		call	a10
		return
;------------------------------------
sda_1		call	a11
		return
;------------------------------------
sda_2to3	btfsc	digitA,D'000'
		goto	sda_3
;------------------------------------
		call	a12
		return
;------------------------------------
sda_3		call	a13
		return
;------------------------------------
;between 4 and 7 (0***01xx)
sda_4bt7	btfsc	digitA,D'001'
		goto	sda_6or7
;010x (4 or 5)
		btfsc	digitA,D'000'
		goto	sda_5
;-------------------------------------
		call	a14
		return
;------------------------------------
sda_5		call	a15
		return
;------------------------------------
;(0***011x)
sda_6or7
		btfsc	digitA,D'000'
		goto	sda_7
;------------------------------------
;eq 6
		call	a16
		return
;------------------------------------
sda_7		call	a17
		return
;------------------------------------
;0***1xxx
sda_gt7		btfsc	digitA,D'002'
		goto	sda_gt12		;0***11xx
		btfsc	digitA,D'001'
		goto	sda_10or11		;0***101x
		btfsc	digitA,D'000'
		goto	sda_9			;0***1001
;eq 8 -------------------------------
;0***1000
		call	a18
		return
;eq 9 -------------------------------
sda_9		call	a19
		return
;------------------------------------
sda_10or11	btfsc	digitA,D'000'
		goto	sda_11
;10
		call	a1a
		return
;------------------------------------
sda_11		call	a1b
		return
;------------------------------------
sda_gt12	btfsc	digitA,D'001'
		goto	sda_14or15		;0***111x
		btfsc	digitA,D'000'
		goto	sda_13			;0***1101
;------------------------------------
;0***1100 = 12 ==> C
		call	a1c
		return
;------------------------------------
sda_13		call	a1d
		return
;------------------------------------
sda_14or15	btfsc	digitA,D'000'
		goto	sda_15
;0***1110
		call	a1e
		return
;------------------------------------
sda_15		call	a1f
		return
;------------------------------------
sda_52		call	a52
		return
;------------------------------------
b3sc		call	a53
		return
;----------------------------------------------------------------------
;----------------------------------------------------------------------
;B
showB		btfsc	button3,D'000'
		goto	b3pdf

		btfsc	digitB,D'007'
		goto	sdb_52
		btfsc	digitB,D'003'
		goto	sdb_gt7		;>7
;<8
		btfsc	digitB,D'002'	;>3 and <8
		goto	sdb_4bt7
;<4
		btfsc	digitB,D'001'
		goto	sdb_2to3	;001x
		btfsc	digitB,D'000'
		goto	sdb_1
;------------------------------------
		call	b10
		return
;------------------------------------
sdb_1		call	b11
		return
;------------------------------------
sdb_2to3	btfsc	digitB,D'000'
		goto	sdb_3
;------------------------------------
		call	b12
		return
;------------------------------------
sdb_3		call	b13
		return
;------------------------------------
;between 4 and 7 (0***01xx)
sdb_4bt7	btfsc	digitB,D'001'
		goto	sdb_6or7
;010x (4 or 5)
		btfsc	digitB,D'000'
		goto	sdb_5
;-------------------------------------
		call	b14
		return
;------------------------------------
sdb_5		call	b15
		return
;------------------------------------
;(0***011x)
sdb_6or7
		btfsc	digitB,D'000'
		goto	sdb_7
;------------------------------------
;eq 6
		call	b16
		return
;------------------------------------
sdb_7		call	b17
		return
;------------------------------------
;0***1xxx
sdb_gt7		btfsc	digitB,D'002'
		goto	sdb_gt12		;0***11xx
		btfsc	digitB,D'001'
		goto	sdb_10or11		;0***101x
		btfsc	digitB,D'000'
		goto	sdb_9			;0***1001
;eq 8 -------------------------------
;0***1000
		call	b18
		return
;eq 9 -------------------------------
sdb_9		call	b19
		return
;------------------------------------
sdb_10or11	btfsc	digitB,D'000'
		goto	sdb_11
;10
		call	b1a
		return
;------------------------------------
sdb_11		call	b1b
		return
;------------------------------------
sdb_gt12	btfsc	digitB,D'001'
		goto	sdb_14or15		;0***111x
		btfsc	digitB,D'000'
		goto	sdb_13			;0***1101
;------------------------------------
;0***1100 = 12 ==> C
		call	b1c
		return
;------------------------------------
sdb_13		call	b1d
		return
;------------------------------------
sdb_14or15	btfsc	digitB,D'000'
		goto	sdb_15
;0***1110
		call	b1e
		return
;------------------------------------
sdb_15		call	b1f
		return
;------------------------------------
sdb_52		call	b52
		return
;------------------------------------
b3pdf		call	b53
		btfsc	actf,D'000'
		call	b10
		btfsc	actf,D'001'
		call	b11
		btfsc	actf,D'002'
		call	b12
		btfsc	actf,D'003'
		call	b13
		btfsc	actf,D'004'
		call	b14
		btfsc	actf,D'005'
		call	b15
		btfsc	actf,D'006'
		call	b16
		btfsc	actf,D'007'
		call	b17
		return
;---------------------------------------------------------------------------
main_test
		call	a10
		call	b10
		call	display01

		call	a11
		call	b11
		call	display01

		call	a12
		call	b12
		call	display01

		call	a13
		call	b13
		call	display01

		call	a14
		call	b14
		call	display01

		call	a15
		call	b15
		call	display01

		call	a16
		call	b16
		call	display01

		call	a17
		call	b17
		call	display01

		call	a18
		call	b18
		call	display01

		call	a19
		call	b19
		call	display01

		call	a1a
		call	b1a
		call	display01

		call	a1b
		call	b1b
		call	display01

		call	a1c
		call	b1c
		call	display01

		call	a1d
		call	b1d
		call	display01

		call	a1e
		call	b1e
		call	display01

		call	a1f
		call	b1f
		call	display01

		return
;--------------------------------------------------------------------------
clr_B		bcf	dataB,D'000'
		bcf	dataB,D'001'
		bcf	dataB,D'002'
		bcf	dataB,D'003'
		bcf	dataB,D'004'
		bcf	dataB,D'005'
		bcf	dataB,D'007'
		return
;-----------------------------------------------------
a10		movlw	B'01011111'	;0*
		movwf	dataA
		bcf	dataB,D'006'
		return
;-----------------------------------------------------
b10		call	clr_B
		bsf	dataB,D'000'
		bsf	dataB,D'001'
		bsf	dataB,D'002'
		bsf	dataB,D'003'
		bsf	dataB,D'004'
		bsf	dataB,D'005'
		return
;-----------------------------------------------------
a11		movlw	B'00001100'	;1*
		movwf	dataA
		bcf	dataB,D'006'
		return
;-----------------------------------------------------
b11		call	clr_B
		bsf	dataB,D'000'
		bsf	dataB,D'003'
		return
;-----------------------------------------------------
a12		movlw	B'00011011'	;2*
		movwf	dataA
		bsf	dataB,D'006'
		return
;-----------------------------------------------------
b12		call	clr_B
		bsf	dataB,D'004'
		bsf	dataB,D'003'
		bsf	dataB,D'007'
		bsf	dataB,D'002'
		bsf	dataB,D'001'
		return
;-----------------------------------------------------
a13		movlw	B'00011110'	;3*
		movwf	dataA
		bsf	dataB,D'006'
		return
;-----------------------------------------------------
b13		call	clr_B
		bsf	dataB,D'004'
		bsf	dataB,D'003'
		bsf	dataB,D'007'
		bsf	dataB,D'000'
		bsf	dataB,D'001'
		return
;-----------------------------------------------------
a14		movlw	B'01001100'	;4*
		movwf	dataA
		bsf	dataB,D'006'
		return
;-----------------------------------------------------
b14		call	clr_B
		bsf	dataB,D'005'
		bsf	dataB,D'007'
		bsf	dataB,D'003'
		bsf	dataB,D'000'
		return
;-----------------------------------------------------
a15		movlw	B'01010110'	;5*
		movwf	dataA
		bsf	dataB,D'006'
		return
;-----------------------------------------------------
b15		call	clr_B
		bsf	dataB,D'004'
		bsf	dataB,D'007'
		bsf	dataB,D'001'
		bsf	dataB,D'005'
		bsf	dataB,D'000'
		return
;-----------------------------------------------------
a16		movlw	B'01010111'	;6*
		movwf	dataA
		bsf	dataB,D'006'
		return
;-----------------------------------------------------
b16		call	clr_B
		bsf	dataB,D'004'
		bsf	dataB,D'007'
		bsf	dataB,D'001'
		bsf	dataB,D'005'
		bsf	dataB,D'000'
		bsf	dataB,D'002'
		return
;-----------------------------------------------------
a17		movlw	B'01011100'	;7*
		movwf	dataA
		bcf	dataB,D'006'
		return
;-----------------------------------------------------
b17		call	clr_B
		bsf	dataB,D'005'
		bsf	dataB,D'004'
		bsf	dataB,D'003'
		bsf	dataB,D'000'
		return
;-----------------------------------------------------
a18		movlw	B'01011111'	;8*
		movwf	dataA
		bsf	dataB,D'006'
		return
;-----------------------------------------------------
b18		call	clr_B
		bsf	dataB,D'000'
		bsf	dataB,D'001'
		bsf	dataB,D'002'
		bsf	dataB,D'003'
		bsf	dataB,D'004'
		bsf	dataB,D'005'
		bsf	dataB,D'007'
		return
;-----------------------------------------------------
a19		movlw	B'01011110'	;9*
		movwf	dataA
		bsf	dataB,D'006'
		return
;-----------------------------------------------------
b19		call	clr_B
		bsf	dataB,D'000'
		bsf	dataB,D'001'
		bsf	dataB,D'003'
		bsf	dataB,D'004'
		bsf	dataB,D'005'
		bsf	dataB,D'007'
		return
;-----------------------------------------------------
a1a		movlw	B'01011101'	;A*
		movwf	dataA
		bsf	dataB,D'006'
		return
;-----------------------------------------------------
b1a		call	clr_B
		bsf	dataB,D'002'
		bsf	dataB,D'005'
		bsf	dataB,D'004'
		bsf	dataB,D'003'
		bsf	dataB,D'007'
		bsf	dataB,D'000'
		return
;-----------------------------------------------------
a1b		movlw	B'01000111'	;b*
		movwf	dataA
		bsf	dataB,D'006'
		return
;-----------------------------------------------------
b1b		call	clr_B
		bsf	dataB,D'005'
		bsf	dataB,D'002'
		bsf	dataB,D'001'
		bsf	dataB,D'000'
		bsf	dataB,D'007'
		return
;-----------------------------------------------------
a1c		movlw	B'01010011'	;C*
		movwf	dataA
		bcf	dataB,D'006'
		return
;-----------------------------------------------------
b1c		call	clr_B
		bsf	dataB,D'004'
		bsf	dataB,D'005'
		bsf	dataB,D'002'
		bsf	dataB,D'001'
		return
;-----------------------------------------------------
a1d		movlw	B'00001111'	;d*
		movwf	dataA
		bsf	dataB,D'006'
		return
;-----------------------------------------------------
b1d		call	clr_B
		bsf	dataB,D'007'
		bsf	dataB,D'003'
		bsf	dataB,D'002'
		bsf	dataB,D'001'
		bsf	dataB,D'000'
		return
;-----------------------------------------------------
a1e		movlw	B'01010011'	;E*
		movwf	dataA
		bsf	dataB,D'006'
		return
;-----------------------------------------------------
b1e		call	clr_B
		bsf	dataB,D'004'
		bsf	dataB,D'007'
		bsf	dataB,D'001'
		bsf	dataB,D'005'
		bsf	dataB,D'002'
		return
;-----------------------------------------------------
a1f		movlw	B'01010001'	;F*
		movwf	dataA
		bsf	dataB,D'006'
		return
;-----------------------------------------------------
b1f		call	clr_B
		bsf	dataB,D'004'
		bsf	dataB,D'007'
		bsf	dataB,D'005'
		bsf	dataB,D'002'
		return
;-----------------------------------------------------
a50		movlw	B'00000000'	;space (nothing)
		movwf	dataA
		bcf	dataB,D'006'
		return
;-----------------------------------------------------
b50		call	clr_B
		return	
;-----------------------------------------------------
a51		movlw	B'00000010'	;_*
		movwf	dataA
		bcf	dataB,D'006'
		return
;-----------------------------------------------------
b51		call	clr_B
		bsf	dataB,D'001'
		return	
;-----------------------------------------------------
a52		movlw	B'00000000'	;-*
		movwf	dataA
		bsf	dataB,D'006'
		return
;-----------------------------------------------------
b52		call	clr_B
		bsf	dataB,D'007'
		return	
;-----------------------------------------------------
a53		movlw	B'01000011'	;L*
		movwf	dataA
		bcf	dataB,D'006'
		return
;-----------------------------------------------------
b53		call	clr_B
		bsf	dataB,D'001'
		bsf	dataB,D'002'
		bsf	dataB,D'005'
		return	
;---------------------------------------------------------------------------
;---------------------------------------------------------------------------
disp_all
	
;off (PORTA/7 = 1)
		bcf	dataA,D'007'
		movf	dataA,0
		movwf	PORTA
		movf	dataB,0
		movwf	PORTB
		call	delay_routine
;on (PORTA/7 = 0)
		comf	dataA,0
		movwf	PORTA
		comf	dataB,0
		movwf	PORTB
		call	delay_routine
		return

;----------------------------------------------------------------------------
;		*********************************************
;		*               delay routine               *
;		*********************************************
delay_routine	MOVLW   D'5'
		MOVWF   TIMER2
DEL_LOOP1       MOVLW   D'255'
		MOVWF   TIMER1
DEL_LOOP2       DECFSZ  TIMER1,F
                GOTO    DEL_LOOP2
                DECFSZ  TIMER2,F
                GOTO    DEL_LOOP1
		return
;----------------------------------------------------------------------------
;----------------------------------------------------------------------------
;----------------------------------------------------------------------------

display01
		call	display02
		call	display02
;buttons --------------------------------------------------------------
		BSF	STATUS,RP0	;Switch to register bank 1
		MOVLW	B'10100000'	;RA7 = input
		MOVWF	TRISA
		BCF	STATUS,RP0	;Switch Back to reg. Bank 0
;test key1 (RB0)
		movlw	B'11111110'
		movwf	PORTB
		btfsc	PORTA,D'005'
		goto	tk2d
;button1 pressed -----------------------
		call	b1p
		goto	tk2
;---------------------------------------
;test key2 (RB1)
tk2d		bcf	button1,D'000'
tk2		movlw	B'11111101'
		movwf	PORTB
		btfsc	PORTA,D'005'
		goto	tk3d
;button2 pressed -----------------------
		call	b2p
		goto	tk3
;---------------------------------------
;test key3 (RB2)
tk3d		bcf	button2,D'000'
tk3		movlw	B'11111011'
		movwf	PORTB
		btfsc	PORTA,D'005'
		goto	jccc
;----------------------------------------
		call	b3p		;button3 pressed
		goto	jccc2
;----------------------------------------
jccc		bcf	button3,D'000'
jccc2		call	disp_all
;----------------------------------------
		BSF	STATUS,RP0	;Switch to register bank 1
		MOVLW	B'00100000'	;RA7 = input
		MOVWF	TRISA
		BCF	STATUS,RP0	;Switch Back to reg. Bank 0
;----------------------------------------------------------------------

		call	display02
		call	display02
		return
;----------------------------------------------------------------------------
;buttons pressed...
b1p		btfss	button1,D'000'
		incf	digitA,1
		bsf	button1,D'000'
		return
;
b2p		btfss	button2,D'000'
		incf	digitB,1
		bsf	button2,D'000'
		return
;
b3p		btfss	button3,D'000'
		goto	do_b3p
		bsf	button3,D'000'
		return

do_b3p		clrf	digitA
		clrf	digitB
		bsf	button3,D'000'
		rlf	actf,1
		btfss	actf,D'007'
		return
		clrf	actf
		bsf	actf,D'000'
		return
;----------------------------------------------------------------------------
;----------------------------------------------------------------------------
;----------------------------------------------------------------------------

display02	call	disp_all
		call	disp_all
		call	disp_all
		call	disp_all
		call	disp_all
		call	disp_all
		call	disp_all

		return
;----------------------------------------------------------------------------
display03	call	display02
		call	display02
		call	display02
		call	display02
		call	display02

		return
;----------------------------------------------------------------------------
		END